#ifndef QPID_FRAMING_AMQP_CLIENTOPERATIONS_H
#define QPID_FRAMING_AMQP_CLIENTOPERATIONS_H
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

///
/// This file was automatically generated from the AMQP specification.
/// Do not edit.
///


#include <sstream> 
#include "qpid/framing/ProtocolVersion.h"
#include "qpid/framing/amqp_structs.h"

namespace qpid {
namespace framing {

class AMQMethodBody;

class AMQP_ClientOperations {
  public:
    class Invoker;              // Declared in ClientInvoker

    virtual ~AMQP_ClientOperations() {}

    virtual ProtocolVersion getVersion() const = 0;

    // Inner classes
    // ==================== class ConnectionHandler ====================
    class ConnectionHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ClientInvoker
          
        ConnectionHandler(){};
        virtual ~ConnectionHandler() {}
        // Protocol methods
    
    virtual void start(uint8_t versionMajor,
    uint8_t versionMinor,
    const FieldTable& serverProperties,
    const string& mechanisms,
    const string& locales) = 0;
    
    virtual void secure(const string& challenge) = 0;
    
    virtual void tune(uint16_t channelMax,
    uint32_t frameMax,
    uint16_t heartbeat) = 0;
    
    virtual void openOk(const string& knownHosts) = 0;
    
    virtual void redirect(const string& host,
    const string& knownHosts) = 0;
    
    virtual void close(uint16_t replyCode,
    const string& replyText,
    uint16_t classId,
    uint16_t methodId) = 0;
    
    virtual void closeOk(    ) = 0;
    }; // class ConnectionHandler
    
    
    // ==================== class SessionHandler ====================
    class SessionHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ClientInvoker
          
        SessionHandler(){};
        virtual ~SessionHandler() {}
        // Protocol methods
    
    virtual void attached(const Uuid& sessionId,
    uint32_t detachedLifetime) = 0;
    
    virtual void flow(bool active) = 0;
    
    virtual void flowOk(bool active) = 0;
    
    virtual void close(    ) = 0;
    
    virtual void closed(uint16_t replyCode,
    const string& replyText) = 0;
    
    virtual void detached(    ) = 0;
    
    virtual void ack(uint32_t cumulativeSeenMark,
    const SequenceNumberSet& seenFrameSet) = 0;
    
    virtual void highWaterMark(uint32_t lastSentMark) = 0;
    
    virtual void solicitAck(    ) = 0;
    }; // class SessionHandler
    
    
    // ==================== class AccessHandler ====================
    class AccessHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ClientInvoker
          
        AccessHandler(){};
        virtual ~AccessHandler() {}
        // Protocol methods
    
    virtual void requestOk(uint16_t ticket) = 0;
    }; // class AccessHandler
    
    
    // ==================== class BasicHandler ====================
    class BasicHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ClientInvoker
          
        BasicHandler(){};
        virtual ~BasicHandler() {}
        // Protocol methods
    
    virtual void consumeOk(const string& consumerTag) = 0;
    
    virtual void getEmpty(const string& clusterId) = 0;
    }; // class BasicHandler
    
    
    // ==================== class FileHandler ====================
    class FileHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ClientInvoker
          
        FileHandler(){};
        virtual ~FileHandler() {}
        // Protocol methods
    
    virtual void qosOk(    ) = 0;
    
    virtual void consumeOk(const string& consumerTag) = 0;
    
    virtual void open(const string& identifier,
    uint64_t contentSize) = 0;
    
    virtual void openOk(uint64_t stagedSize) = 0;
    
    virtual void deliver(const string& consumerTag,
    uint64_t deliveryTag,
    bool redelivered,
    const string& exchange,
    const string& routingKey,
    const string& identifier) = 0;
    }; // class FileHandler
    
    
    // ==================== class StreamHandler ====================
    class StreamHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ClientInvoker
          
        StreamHandler(){};
        virtual ~StreamHandler() {}
        // Protocol methods
    
    virtual void qosOk(    ) = 0;
    
    virtual void consumeOk(const string& consumerTag) = 0;
    }; // class StreamHandler
    
    
    // ==================== class MessageHandler ====================
    class MessageHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ClientInvoker
          
        MessageHandler(){};
        virtual ~MessageHandler() {}
        // Protocol methods
    
    virtual void reject(const SequenceNumberSet& transfers,
    uint16_t code,
    const string& text) = 0;
    
    virtual void acquired(const SequenceNumberSet& transfers) = 0;
    
    virtual void release(const SequenceNumberSet& transfers) = 0;
    
    virtual void open(const string& reference) = 0;
    
    virtual void close(const string& reference) = 0;
    
    virtual void append(const string& reference,
    const string& bytes) = 0;
    
    virtual void checkpoint(const string& reference,
    const string& identifier) = 0;
    
    virtual void resume(const string& reference,
    const string& identifier) = 0;
    
    virtual void flowMode(const string& destination,
    uint8_t mode) = 0;
    
    virtual void flow(const string& destination,
    uint8_t unit,
    uint32_t value) = 0;
    
    virtual void stop(const string& destination) = 0;
    
    virtual void empty(    ) = 0;
    
    virtual void offset(uint64_t value) = 0;
    }; // class MessageHandler
    
    
    // ==================== class ExecutionHandler ====================
    class ExecutionHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ClientInvoker
          
        ExecutionHandler(){};
        virtual ~ExecutionHandler() {}
        // Protocol methods
    
    virtual void flush(    ) = 0;
    
    virtual void complete(uint32_t cumulativeExecutionMark,
    const SequenceNumberSet& rangedExecutionSet) = 0;
    
    virtual void noop(    ) = 0;
    
    virtual void result(uint32_t commandId,
    const string& data) = 0;
    
    virtual void sync(    ) = 0;
    }; // class ExecutionHandler
    
    
    // ==================== class Connection010Handler ====================
    class Connection010Handler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ClientInvoker
          
        Connection010Handler(){};
        virtual ~Connection010Handler() {}
        // Protocol methods
    
    virtual void start(const FieldTable& serverProperties,
    const Array& mechanisms,
    const Array& locales) = 0;
    
    virtual void secure(const string& challenge) = 0;
    
    virtual void tune(uint16_t channelMax,
    uint16_t frameMax,
    uint16_t heartbeatMin,
    uint16_t heartbeatMax) = 0;
    
    virtual void openOk(const Array& knownHosts) = 0;
    
    virtual void redirect(const string& host,
    const string& knownHosts) = 0;
    
    virtual void close(uint16_t replyCode,
    const string& replyText,
    uint16_t classId,
    uint16_t methodId) = 0;
    
    virtual void closeOk(    ) = 0;
    }; // class Connection010Handler
    
    
    // ==================== class Session010Handler ====================
    class Session010Handler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ClientInvoker
          
        Session010Handler(){};
        virtual ~Session010Handler() {}
        // Protocol methods
    
    virtual void attach(const string& name,
    bool force) = 0;
    
    virtual void attached(const string& name) = 0;
    
    virtual void detach(const string& name) = 0;
    
    virtual void detached(const string& name,
    uint8_t detachCode) = 0;
    
    virtual void requestTimeout(uint32_t timeout) = 0;
    
    virtual void timeout(uint32_t timeout) = 0;
    
    virtual void commandPoint(uint32_t commandId,
    uint64_t commandOffset) = 0;
    
    virtual void expected(const SequenceSet& commands,
    const Array& fragments) = 0;
    
    virtual void confirmed(const SequenceSet& commands,
    const Array& fragments) = 0;
    
    virtual void completed(const SequenceSet& commands,
    bool timelyReply) = 0;
    
    virtual void knownCompleted(const SequenceSet& commands) = 0;
    
    virtual void flush(bool expected,
    bool confirmed,
    bool completed) = 0;
    
    virtual void gap(const SequenceSet& commands) = 0;
    }; // class Session010Handler
    
    
    // ==================== class Execution010Handler ====================
    class Execution010Handler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ClientInvoker
          
        Execution010Handler(){};
        virtual ~Execution010Handler() {}
        // Protocol methods
    
    virtual void sync(    ) = 0;
    
    virtual void result(uint32_t commandId,
    const string& value) = 0;
    
    virtual void exception(uint16_t errorCode,
    uint32_t commandId,
    uint8_t classCode,
    uint8_t commandCode,
    uint8_t fieldIndex,
    const string& description,
    const FieldTable& errorInfo) = 0;
    }; // class Execution010Handler
    
    
    // ==================== class Message010Handler ====================
    class Message010Handler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ClientInvoker
          
        Message010Handler(){};
        virtual ~Message010Handler() {}
        // Protocol methods
    
    virtual void transfer(const string& destination,
    uint8_t acceptMode,
    uint8_t acquireMode) = 0;
    
    virtual void accept(const SequenceSet& commands) = 0;
    
    virtual void reject(const SequenceSet& commands,
    uint16_t code,
    const string& text) = 0;
    }; // class Message010Handler
    
    

    // Method handler get methods

    virtual ConnectionHandler* getConnectionHandler() = 0;
    virtual SessionHandler* getSessionHandler() = 0;
    virtual AccessHandler* getAccessHandler() = 0;
    virtual BasicHandler* getBasicHandler() = 0;
    virtual FileHandler* getFileHandler() = 0;
    virtual StreamHandler* getStreamHandler() = 0;
    virtual MessageHandler* getMessageHandler() = 0;
    virtual ExecutionHandler* getExecutionHandler() = 0;
    virtual Connection010Handler* getConnection010Handler() = 0;
    virtual Session010Handler* getSession010Handler() = 0;
    virtual Execution010Handler* getExecution010Handler() = 0;
    virtual Message010Handler* getMessage010Handler() = 0;
}; /* class AMQP_ClientOperations */
}}
#endif  /*!QPID_FRAMING_AMQP_CLIENTOPERATIONS_H*/
