#ifndef QPID_FRAMING_AMQP_CLIENTPROXY_H
#define QPID_FRAMING_AMQP_CLIENTPROXY_H
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

///
/// This file was automatically generated from the AMQP specification.
/// Do not edit.
///


#include "qpid/framing/Proxy.h"
#include "qpid/framing/Array.h"
#include "qpid/framing/amqp_types.h"
#include "qpid/framing/amqp_structs.h"

namespace qpid {
namespace framing {

class AMQP_ClientProxy:
    public Proxy
{
  public:
    AMQP_ClientProxy(FrameHandler& out);
    
    class Connection:
        Proxy
    {
        public:
        Connection(FrameHandler& f) : Proxy(f) {}
        static Connection& get(AMQP_ClientProxy& proxy) { return proxy.getConnection(); }
        virtual void start(uint8_t versionMajor,
                    uint8_t versionMinor,
                    const FieldTable& serverProperties,
                    const string& mechanisms,
                    const string& locales);
        
        virtual void secure(const string& challenge);
        
        virtual void tune(uint16_t channelMax,
                    uint32_t frameMax,
                    uint16_t heartbeat);
        
        virtual void openOk(const string& knownHosts);
        
        virtual void redirect(const string& host,
                    const string& knownHosts);
        
        virtual void close(uint16_t replyCode,
                    const string& replyText,
                    uint16_t classId,
                    uint16_t methodId);
        
        virtual void closeOk();
        
    };
    
    Connection& getConnection() { return connectionProxy; }
    
    class Session:
        Proxy
    {
        public:
        Session(FrameHandler& f) : Proxy(f) {}
        static Session& get(AMQP_ClientProxy& proxy) { return proxy.getSession(); }
        virtual void attached(const Uuid& sessionId,
                    uint32_t detachedLifetime);
        
        virtual void flow(bool active);
        
        virtual void flowOk(bool active);
        
        virtual void close();
        
        virtual void closed(uint16_t replyCode,
                    const string& replyText);
        
        virtual void detached();
        
        virtual void ack(uint32_t cumulativeSeenMark,
                    const SequenceNumberSet& seenFrameSet);
        
        virtual void highWaterMark(uint32_t lastSentMark);
        
        virtual void solicitAck();
        
    };
    
    Session& getSession() { return sessionProxy; }
    
    class Access:
        Proxy
    {
        public:
        Access(FrameHandler& f) : Proxy(f) {}
        static Access& get(AMQP_ClientProxy& proxy) { return proxy.getAccess(); }
        virtual void requestOk(uint16_t ticket);
        
    };
    
    Access& getAccess() { return accessProxy; }
    
    class Exchange:
        Proxy
    {
        public:
        Exchange(FrameHandler& f) : Proxy(f) {}
        static Exchange& get(AMQP_ClientProxy& proxy) { return proxy.getExchange(); }
    };
    
    Exchange& getExchange() { return exchangeProxy; }
    
    class Queue:
        Proxy
    {
        public:
        Queue(FrameHandler& f) : Proxy(f) {}
        static Queue& get(AMQP_ClientProxy& proxy) { return proxy.getQueue(); }
    };
    
    Queue& getQueue() { return queueProxy; }
    
    class Basic:
        Proxy
    {
        public:
        Basic(FrameHandler& f) : Proxy(f) {}
        static Basic& get(AMQP_ClientProxy& proxy) { return proxy.getBasic(); }
        virtual void consumeOk(const string& consumerTag);
        
        virtual void deliver(const string& consumerTag,
                    uint64_t deliveryTag,
                    bool redelivered,
                    const string& exchange,
                    const string& routingKey);
        
        virtual void getOk(uint64_t deliveryTag,
                    bool redelivered,
                    const string& exchange,
                    const string& routingKey,
                    uint32_t messageCount);
        
        virtual void getEmpty(const string& clusterId);
        
    };
    
    Basic& getBasic() { return basicProxy; }
    
    class File:
        Proxy
    {
        public:
        File(FrameHandler& f) : Proxy(f) {}
        static File& get(AMQP_ClientProxy& proxy) { return proxy.getFile(); }
        virtual void qosOk();
        
        virtual void consumeOk(const string& consumerTag);
        
        virtual void open(const string& identifier,
                    uint64_t contentSize);
        
        virtual void openOk(uint64_t stagedSize);
        
        virtual void stage();
        
        virtual void return_(uint16_t replyCode,
                    const string& replyText,
                    const string& exchange,
                    const string& routingKey);
        
        virtual void deliver(const string& consumerTag,
                    uint64_t deliveryTag,
                    bool redelivered,
                    const string& exchange,
                    const string& routingKey,
                    const string& identifier);
        
    };
    
    File& getFile() { return fileProxy; }
    
    class Stream:
        Proxy
    {
        public:
        Stream(FrameHandler& f) : Proxy(f) {}
        static Stream& get(AMQP_ClientProxy& proxy) { return proxy.getStream(); }
        virtual void qosOk();
        
        virtual void consumeOk(const string& consumerTag);
        
        virtual void return_(uint16_t replyCode,
                    const string& replyText,
                    const string& exchange,
                    const string& routingKey);
        
        virtual void deliver(const string& consumerTag,
                    uint64_t deliveryTag,
                    const string& exchange,
                    const string& queue);
        
    };
    
    Stream& getStream() { return streamProxy; }
    
    class Tx:
        Proxy
    {
        public:
        Tx(FrameHandler& f) : Proxy(f) {}
        static Tx& get(AMQP_ClientProxy& proxy) { return proxy.getTx(); }
    };
    
    Tx& getTx() { return txProxy; }
    
    class DtxDemarcation:
        Proxy
    {
        public:
        DtxDemarcation(FrameHandler& f) : Proxy(f) {}
        static DtxDemarcation& get(AMQP_ClientProxy& proxy) { return proxy.getDtxDemarcation(); }
    };
    
    DtxDemarcation& getDtxDemarcation() { return dtxDemarcationProxy; }
    
    class DtxCoordination:
        Proxy
    {
        public:
        DtxCoordination(FrameHandler& f) : Proxy(f) {}
        static DtxCoordination& get(AMQP_ClientProxy& proxy) { return proxy.getDtxCoordination(); }
    };
    
    DtxCoordination& getDtxCoordination() { return dtxCoordinationProxy; }
    
    class Tunnel:
        Proxy
    {
        public:
        Tunnel(FrameHandler& f) : Proxy(f) {}
        static Tunnel& get(AMQP_ClientProxy& proxy) { return proxy.getTunnel(); }
    };
    
    Tunnel& getTunnel() { return tunnelProxy; }
    
    class Message:
        Proxy
    {
        public:
        Message(FrameHandler& f) : Proxy(f) {}
        static Message& get(AMQP_ClientProxy& proxy) { return proxy.getMessage(); }
        virtual void transfer(uint16_t ticket,
                    const string& destination,
                    uint8_t confirmMode,
                    uint8_t acquireMode);
        
        virtual void reject(const SequenceNumberSet& transfers,
                    uint16_t code,
                    const string& text);
        
        virtual void acquired(const SequenceNumberSet& transfers);
        
        virtual void release(const SequenceNumberSet& transfers);
        
        virtual void open(const string& reference);
        
        virtual void close(const string& reference);
        
        virtual void append(const string& reference,
                    const string& bytes);
        
        virtual void checkpoint(const string& reference,
                    const string& identifier);
        
        virtual void resume(const string& reference,
                    const string& identifier);
        
        virtual void flowMode(const string& destination,
                    uint8_t mode);
        
        virtual void flow(const string& destination,
                    uint8_t unit,
                    uint32_t value);
        
        virtual void stop(const string& destination);
        
        virtual void empty();
        
        virtual void offset(uint64_t value);
        
    };
    
    Message& getMessage() { return messageProxy; }
    
    class Binding:
        Proxy
    {
        public:
        Binding(FrameHandler& f) : Proxy(f) {}
        static Binding& get(AMQP_ClientProxy& proxy) { return proxy.getBinding(); }
    };
    
    Binding& getBinding() { return bindingProxy; }
    
    class Execution:
        Proxy
    {
        public:
        Execution(FrameHandler& f) : Proxy(f) {}
        static Execution& get(AMQP_ClientProxy& proxy) { return proxy.getExecution(); }
        virtual void flush();
        
        virtual void complete(uint32_t cumulativeExecutionMark,
                    const SequenceNumberSet& rangedExecutionSet);
        
        virtual void noop();
        
        virtual void result(uint32_t commandId,
                    const string& data);
        
        virtual void sync();
        
    };
    
    Execution& getExecution() { return executionProxy; }
    
    class Connection010:
        Proxy
    {
        public:
        Connection010(FrameHandler& f) : Proxy(f) {}
        static Connection010& get(AMQP_ClientProxy& proxy) { return proxy.getConnection010(); }
        virtual void start(const FieldTable& serverProperties,
                    const Array& mechanisms,
                    const Array& locales);
        
        virtual void secure(const string& challenge);
        
        virtual void tune(uint16_t channelMax,
                    uint16_t frameMax,
                    uint16_t heartbeatMin,
                    uint16_t heartbeatMax);
        
        virtual void openOk(const Array& knownHosts);
        
        virtual void redirect(const string& host,
                    const string& knownHosts);
        
        virtual void close(uint16_t replyCode,
                    const string& replyText,
                    uint16_t classId,
                    uint16_t methodId);
        
        virtual void closeOk();
        
    };
    
    Connection010& getConnection010() { return connection010Proxy; }
    
    class Session010:
        Proxy
    {
        public:
        Session010(FrameHandler& f) : Proxy(f) {}
        static Session010& get(AMQP_ClientProxy& proxy) { return proxy.getSession010(); }
        virtual void attach(const string& name,
                    bool force);
        
        virtual void attached(const string& name);
        
        virtual void detach(const string& name);
        
        virtual void detached(const string& name,
                    uint8_t detachCode);
        
        virtual void requestTimeout(uint32_t timeout);
        
        virtual void timeout(uint32_t timeout);
        
        virtual void commandPoint(uint32_t commandId,
                    uint64_t commandOffset);
        
        virtual void expected(const SequenceSet& commands,
                    const Array& fragments);
        
        virtual void confirmed(const SequenceSet& commands,
                    const Array& fragments);
        
        virtual void completed(const SequenceSet& commands,
                    bool timelyReply);
        
        virtual void knownCompleted(const SequenceSet& commands);
        
        virtual void flush(bool expected,
                    bool confirmed,
                    bool completed);
        
        virtual void gap(const SequenceSet& commands);
        
    };
    
    Session010& getSession010() { return session010Proxy; }
    
    class Execution010:
        Proxy
    {
        public:
        Execution010(FrameHandler& f) : Proxy(f) {}
        static Execution010& get(AMQP_ClientProxy& proxy) { return proxy.getExecution010(); }
        virtual void sync();
        
        virtual void result(uint32_t commandId,
                    const string& value);
        
        virtual void exception(uint16_t errorCode,
                    uint32_t commandId,
                    uint8_t classCode,
                    uint8_t commandCode,
                    uint8_t fieldIndex,
                    const string& description,
                    const FieldTable& errorInfo);
        
    };
    
    Execution010& getExecution010() { return execution010Proxy; }
    
    class Message010:
        Proxy
    {
        public:
        Message010(FrameHandler& f) : Proxy(f) {}
        static Message010& get(AMQP_ClientProxy& proxy) { return proxy.getMessage010(); }
        virtual void transfer(const string& destination,
                    uint8_t acceptMode,
                    uint8_t acquireMode);
        
        virtual void accept(const SequenceSet& commands);
        
        virtual void reject(const SequenceSet& commands,
                    uint16_t code,
                    const string& text);
        
    };
    
    Message010& getMessage010() { return message010Proxy; }
    
    class Tx010:
        Proxy
    {
        public:
        Tx010(FrameHandler& f) : Proxy(f) {}
        static Tx010& get(AMQP_ClientProxy& proxy) { return proxy.getTx010(); }
    };
    
    Tx010& getTx010() { return tx010Proxy; }
    
    class Dtx010:
        Proxy
    {
        public:
        Dtx010(FrameHandler& f) : Proxy(f) {}
        static Dtx010& get(AMQP_ClientProxy& proxy) { return proxy.getDtx010(); }
    };
    
    Dtx010& getDtx010() { return dtx010Proxy; }
    
    class Exchange010:
        Proxy
    {
        public:
        Exchange010(FrameHandler& f) : Proxy(f) {}
        static Exchange010& get(AMQP_ClientProxy& proxy) { return proxy.getExchange010(); }
    };
    
    Exchange010& getExchange010() { return exchange010Proxy; }
    
    class Queue010:
        Proxy
    {
        public:
        Queue010(FrameHandler& f) : Proxy(f) {}
        static Queue010& get(AMQP_ClientProxy& proxy) { return proxy.getQueue010(); }
    };
    
    Queue010& getQueue010() { return queue010Proxy; }
    
    class Cluster:
        Proxy
    {
        public:
        Cluster(FrameHandler& f) : Proxy(f) {}
        static Cluster& get(AMQP_ClientProxy& proxy) { return proxy.getCluster(); }
    };
    
    Cluster& getCluster() { return clusterProxy; }
    
  private:
    Connection connectionProxy;
    Session sessionProxy;
    Access accessProxy;
    Exchange exchangeProxy;
    Queue queueProxy;
    Basic basicProxy;
    File fileProxy;
    Stream streamProxy;
    Tx txProxy;
    DtxDemarcation dtxDemarcationProxy;
    DtxCoordination dtxCoordinationProxy;
    Tunnel tunnelProxy;
    Message messageProxy;
    Binding bindingProxy;
    Execution executionProxy;
    Connection010 connection010Proxy;
    Session010 session010Proxy;
    Execution010 execution010Proxy;
    Message010 message010Proxy;
    Tx010 tx010Proxy;
    Dtx010 dtx010Proxy;
    Exchange010 exchange010Proxy;
    Queue010 queue010Proxy;
    Cluster clusterProxy;
};

}} // namespace qpid::framing

#endif  /*!QPID_FRAMING_AMQP_CLIENTPROXY_H*/
