#ifndef QPID_FRAMING_AMQP_SERVEROPERATIONS_H
#define QPID_FRAMING_AMQP_SERVEROPERATIONS_H
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

///
/// This file was automatically generated from the AMQP specification.
/// Do not edit.
///


#include <sstream> 
#include "qpid/framing/ProtocolVersion.h"
#include "qpid/framing/amqp_structs.h"

namespace qpid {
namespace framing {

class AMQMethodBody;

class AMQP_ServerOperations {
  public:
    class Invoker;              // Declared in ServerInvoker

    virtual ~AMQP_ServerOperations() {}

    virtual ProtocolVersion getVersion() const = 0;

    // Inner classes
    // ==================== class ConnectionHandler ====================
    class ConnectionHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        ConnectionHandler(){};
        virtual ~ConnectionHandler() {}
        // Protocol methods
    
    virtual void startOk(const FieldTable& clientProperties,
    const string& mechanism,
    const string& response,
    const string& locale) = 0;
    
    virtual void secureOk(const string& response) = 0;
    
    virtual void tuneOk(uint16_t channelMax,
    uint32_t frameMax,
    uint16_t heartbeat) = 0;
    
    virtual void open(const string& virtualHost,
    const string& capabilities,
    bool insist) = 0;
    
    virtual void close(uint16_t replyCode,
    const string& replyText,
    uint16_t classId,
    uint16_t methodId) = 0;
    
    virtual void closeOk(    ) = 0;
    }; // class ConnectionHandler
    
    
    // ==================== class SessionHandler ====================
    class SessionHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        SessionHandler(){};
        virtual ~SessionHandler() {}
        // Protocol methods
    
    virtual void open(uint32_t detachedLifetime) = 0;
    
    virtual void flow(bool active) = 0;
    
    virtual void flowOk(bool active) = 0;
    
    virtual void close(    ) = 0;
    
    virtual void closed(uint16_t replyCode,
    const string& replyText) = 0;
    
    virtual void resume(const Uuid& sessionId) = 0;
    
    virtual void suspend(    ) = 0;
    
    virtual void ack(uint32_t cumulativeSeenMark,
    const SequenceNumberSet& seenFrameSet) = 0;
    
    virtual void highWaterMark(uint32_t lastSentMark) = 0;
    
    virtual void solicitAck(    ) = 0;
    }; // class SessionHandler
    
    
    // ==================== class AccessHandler ====================
    class AccessHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        AccessHandler(){};
        virtual ~AccessHandler() {}
        // Protocol methods
    
    virtual void request(const string& realm,
    bool exclusive,
    bool passive,
    bool active,
    bool write,
    bool read) = 0;
    }; // class AccessHandler
    
    
    // ==================== class ExchangeHandler ====================
    class ExchangeHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        ExchangeHandler(){};
        virtual ~ExchangeHandler() {}
        // Protocol methods
    
    virtual void declare(uint16_t ticket,
    const string& exchange,
    const string& type,
    const string& alternateExchange,
    bool passive,
    bool durable,
    bool autoDelete,
    const FieldTable& arguments) = 0;
    
    virtual void delete_(uint16_t ticket,
    const string& exchange,
    bool ifUnused) = 0;
    
    virtual ExchangeQueryResult query(uint16_t ticket,
    const string& name) = 0;
    }; // class ExchangeHandler
    
    
    // ==================== class QueueHandler ====================
    class QueueHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        QueueHandler(){};
        virtual ~QueueHandler() {}
        // Protocol methods
    
    virtual void declare(uint16_t ticket,
    const string& queue,
    const string& alternateExchange,
    bool passive,
    bool durable,
    bool exclusive,
    bool autoDelete,
    const FieldTable& arguments) = 0;
    
    virtual void bind(uint16_t ticket,
    const string& queue,
    const string& exchange,
    const string& routingKey,
    const FieldTable& arguments) = 0;
    
    virtual void unbind(uint16_t ticket,
    const string& queue,
    const string& exchange,
    const string& routingKey,
    const FieldTable& arguments) = 0;
    
    virtual void purge(uint16_t ticket,
    const string& queue) = 0;
    
    virtual void delete_(uint16_t ticket,
    const string& queue,
    bool ifUnused,
    bool ifEmpty) = 0;
    
    virtual QueueQueryResult query(const string& queue) = 0;
    }; // class QueueHandler
    
    
    // ==================== class BasicHandler ====================
    class BasicHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        BasicHandler(){};
        virtual ~BasicHandler() {}
        // Protocol methods
    
    virtual void qos(uint32_t prefetchSize,
    uint16_t prefetchCount,
    bool global) = 0;
    
    virtual void consume(uint16_t ticket,
    const string& queue,
    const string& consumerTag,
    bool noLocal,
    bool noAck,
    bool exclusive,
    bool nowait,
    const FieldTable& arguments) = 0;
    
    virtual void cancel(const string& consumerTag) = 0;
    
    virtual void get(uint16_t ticket,
    const string& queue,
    bool noAck) = 0;
    
    virtual void ack(uint64_t deliveryTag,
    bool multiple) = 0;
    
    virtual void reject(uint64_t deliveryTag,
    bool requeue) = 0;
    
    virtual void recover(bool requeue) = 0;
    }; // class BasicHandler
    
    
    // ==================== class FileHandler ====================
    class FileHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        FileHandler(){};
        virtual ~FileHandler() {}
        // Protocol methods
    
    virtual void qos(uint32_t prefetchSize,
    uint16_t prefetchCount,
    bool global) = 0;
    
    virtual void consume(uint16_t ticket,
    const string& queue,
    const string& consumerTag,
    bool noLocal,
    bool noAck,
    bool exclusive,
    bool nowait,
    const FieldTable& filter) = 0;
    
    virtual void cancel(const string& consumerTag) = 0;
    
    virtual void open(const string& identifier,
    uint64_t contentSize) = 0;
    
    virtual void openOk(uint64_t stagedSize) = 0;
    
    virtual void publish(uint16_t ticket,
    const string& exchange,
    const string& routingKey,
    bool mandatory,
    bool immediate,
    const string& identifier) = 0;
    
    virtual void ack(uint64_t deliveryTag,
    bool multiple) = 0;
    
    virtual void reject(uint64_t deliveryTag,
    bool requeue) = 0;
    }; // class FileHandler
    
    
    // ==================== class StreamHandler ====================
    class StreamHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        StreamHandler(){};
        virtual ~StreamHandler() {}
        // Protocol methods
    
    virtual void qos(uint32_t prefetchSize,
    uint16_t prefetchCount,
    uint32_t consumeRate,
    bool global) = 0;
    
    virtual void consume(uint16_t ticket,
    const string& queue,
    const string& consumerTag,
    bool noLocal,
    bool exclusive,
    bool nowait,
    const FieldTable& filter) = 0;
    
    virtual void cancel(const string& consumerTag) = 0;
    }; // class StreamHandler
    
    
    // ==================== class TxHandler ====================
    class TxHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        TxHandler(){};
        virtual ~TxHandler() {}
        // Protocol methods
    
    virtual void select(    ) = 0;
    
    virtual void commit(    ) = 0;
    
    virtual void rollback(    ) = 0;
    }; // class TxHandler
    
    
    // ==================== class DtxDemarcationHandler ====================
    class DtxDemarcationHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        DtxDemarcationHandler(){};
        virtual ~DtxDemarcationHandler() {}
        // Protocol methods
    
    virtual void select(    ) = 0;
    
    virtual DtxDemarcationStartResult start(uint16_t ticket,
    const string& xid,
    bool join,
    bool resume) = 0;
    
    virtual DtxDemarcationEndResult end(uint16_t ticket,
    const string& xid,
    bool fail,
    bool suspend) = 0;
    }; // class DtxDemarcationHandler
    
    
    // ==================== class DtxCoordinationHandler ====================
    class DtxCoordinationHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        DtxCoordinationHandler(){};
        virtual ~DtxCoordinationHandler() {}
        // Protocol methods
    
    virtual DtxCoordinationCommitResult commit(uint16_t ticket,
    const string& xid,
    bool onePhase) = 0;
    
    virtual void forget(uint16_t ticket,
    const string& xid) = 0;
    
    virtual DtxCoordinationGetTimeoutResult getTimeout(const string& xid) = 0;
    
    virtual DtxCoordinationPrepareResult prepare(uint16_t ticket,
    const string& xid) = 0;
    
    virtual DtxCoordinationRecoverResult recover(uint16_t ticket,
    bool startscan,
    bool endscan) = 0;
    
    virtual DtxCoordinationRollbackResult rollback(uint16_t ticket,
    const string& xid) = 0;
    
    virtual void setTimeout(uint16_t ticket,
    const string& xid,
    uint32_t timeout) = 0;
    }; // class DtxCoordinationHandler
    
    
    // ==================== class TunnelHandler ====================
    class TunnelHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        TunnelHandler(){};
        virtual ~TunnelHandler() {}
        // Protocol methods
    }; // class TunnelHandler
    
    
    // ==================== class MessageHandler ====================
    class MessageHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        MessageHandler(){};
        virtual ~MessageHandler() {}
        // Protocol methods
    
    virtual void reject(const SequenceNumberSet& transfers,
    uint16_t code,
    const string& text) = 0;
    
    virtual void acquire(const SequenceNumberSet& transfers,
    uint8_t mode) = 0;
    
    virtual void release(const SequenceNumberSet& transfers) = 0;
    
    virtual void subscribe(uint16_t ticket,
    const string& queue,
    const string& destination,
    bool noLocal,
    uint8_t confirmMode,
    uint8_t acquireMode,
    bool exclusive,
    const FieldTable& filter) = 0;
    
    virtual void cancel(const string& destination) = 0;
    
    virtual void get(uint16_t ticket,
    const string& queue,
    const string& destination,
    bool noAck) = 0;
    
    virtual void recover(bool requeue) = 0;
    
    virtual void open(const string& reference) = 0;
    
    virtual void close(const string& reference) = 0;
    
    virtual void append(const string& reference,
    const string& bytes) = 0;
    
    virtual void checkpoint(const string& reference,
    const string& identifier) = 0;
    
    virtual void resume(const string& reference,
    const string& identifier) = 0;
    
    virtual void qos(uint32_t prefetchSize,
    uint16_t prefetchCount,
    bool global) = 0;
    
    virtual void flowMode(const string& destination,
    uint8_t mode) = 0;
    
    virtual void flow(const string& destination,
    uint8_t unit,
    uint32_t value) = 0;
    
    virtual void flush(const string& destination) = 0;
    
    virtual void stop(const string& destination) = 0;
    
    virtual void empty(    ) = 0;
    
    virtual void offset(uint64_t value) = 0;
    }; // class MessageHandler
    
    
    // ==================== class BindingHandler ====================
    class BindingHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        BindingHandler(){};
        virtual ~BindingHandler() {}
        // Protocol methods
    
    virtual BindingQueryResult query(uint16_t ticket,
    const string& exchange,
    const string& queue,
    const string& routingKey,
    const FieldTable& arguments) = 0;
    }; // class BindingHandler
    
    
    // ==================== class ExecutionHandler ====================
    class ExecutionHandler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        ExecutionHandler(){};
        virtual ~ExecutionHandler() {}
        // Protocol methods
    
    virtual void flush(    ) = 0;
    
    virtual void complete(uint32_t cumulativeExecutionMark,
    const SequenceNumberSet& rangedExecutionSet) = 0;
    
    virtual void noop(    ) = 0;
    
    virtual void result(uint32_t commandId,
    const string& data) = 0;
    
    virtual void sync(    ) = 0;
    }; // class ExecutionHandler
    
    
    // ==================== class Connection010Handler ====================
    class Connection010Handler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        Connection010Handler(){};
        virtual ~Connection010Handler() {}
        // Protocol methods
    
    virtual void startOk(const FieldTable& clientProperties,
    const string& mechanism,
    const string& response,
    const string& locale) = 0;
    
    virtual void secureOk(const string& response) = 0;
    
    virtual void tuneOk(uint16_t channelMax,
    uint16_t frameMax,
    uint16_t heartbeat) = 0;
    
    virtual void open(const string& virtualHost,
    const Array& capabilities,
    bool insist) = 0;
    
    virtual void heartbeat(    ) = 0;
    
    virtual void close(uint16_t replyCode,
    const string& replyText,
    uint16_t classId,
    uint16_t methodId) = 0;
    
    virtual void closeOk(    ) = 0;
    }; // class Connection010Handler
    
    
    // ==================== class Session010Handler ====================
    class Session010Handler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        Session010Handler(){};
        virtual ~Session010Handler() {}
        // Protocol methods
    
    virtual void attach(const string& name,
    bool force) = 0;
    
    virtual void attached(const string& name) = 0;
    
    virtual void detach(const string& name) = 0;
    
    virtual void detached(const string& name,
    uint8_t detachCode) = 0;
    
    virtual void requestTimeout(uint32_t timeout) = 0;
    
    virtual void timeout(uint32_t timeout) = 0;
    
    virtual void commandPoint(uint32_t commandId,
    uint64_t commandOffset) = 0;
    
    virtual void expected(const SequenceSet& commands,
    const Array& fragments) = 0;
    
    virtual void confirmed(const SequenceSet& commands,
    const Array& fragments) = 0;
    
    virtual void completed(const SequenceSet& commands,
    bool timelyReply) = 0;
    
    virtual void knownCompleted(const SequenceSet& commands) = 0;
    
    virtual void flush(bool expected,
    bool confirmed,
    bool completed) = 0;
    
    virtual void gap(const SequenceSet& commands) = 0;
    }; // class Session010Handler
    
    
    // ==================== class Execution010Handler ====================
    class Execution010Handler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        Execution010Handler(){};
        virtual ~Execution010Handler() {}
        // Protocol methods
    
    virtual void sync(    ) = 0;
    
    virtual void result(uint32_t commandId,
    const string& value) = 0;
    
    virtual void exception(uint16_t errorCode,
    uint32_t commandId,
    uint8_t classCode,
    uint8_t commandCode,
    uint8_t fieldIndex,
    const string& description,
    const FieldTable& errorInfo) = 0;
    }; // class Execution010Handler
    
    
    // ==================== class Message010Handler ====================
    class Message010Handler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        Message010Handler(){};
        virtual ~Message010Handler() {}
        // Protocol methods
    
    virtual void transfer(const string& destination,
    uint8_t acceptMode,
    uint8_t acquireMode) = 0;
    
    virtual void accept(const SequenceSet& commands) = 0;
    
    virtual void reject(const SequenceSet& commands,
    uint16_t code,
    const string& text) = 0;
    
    virtual void release(const SequenceSet& commands,
    bool setRedelivered) = 0;
    
    virtual Message010AcquireResult acquire(const SequenceSet& transfers) = 0;
    
    virtual void subscribe(const string& queue,
    const string& destination,
    uint8_t acceptMode,
    uint8_t acquireMode,
    bool exclusive,
    const string& resumeId,
    uint64_t resumeTtl,
    const FieldTable& arguments) = 0;
    
    virtual void cancel(const string& destination) = 0;
    
    virtual void setFlowMode(const string& destination,
    uint8_t flowMode) = 0;
    
    virtual void flow(const string& destination,
    uint8_t unit,
    uint32_t value) = 0;
    
    virtual void flush(const string& destination) = 0;
    
    virtual void stop(const string& destination) = 0;
    }; // class Message010Handler
    
    
    // ==================== class Tx010Handler ====================
    class Tx010Handler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        Tx010Handler(){};
        virtual ~Tx010Handler() {}
        // Protocol methods
    
    virtual void select(    ) = 0;
    
    virtual void commit(    ) = 0;
    
    virtual void rollback(    ) = 0;
    }; // class Tx010Handler
    
    
    // ==================== class Dtx010Handler ====================
    class Dtx010Handler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        Dtx010Handler(){};
        virtual ~Dtx010Handler() {}
        // Protocol methods
    
    virtual void select(    ) = 0;
    
    virtual Dtx010StartResult start(const Xid010& xid,
    bool join,
    bool resume) = 0;
    
    virtual Dtx010EndResult end(const Xid010& xid,
    bool fail,
    bool suspend) = 0;
    
    virtual Dtx010CommitResult commit(const Xid010& xid,
    bool onePhase) = 0;
    
    virtual void forget(const Xid010& xid) = 0;
    
    virtual Dtx010GetTimeoutResult getTimeout(const Xid010& xid) = 0;
    
    virtual Dtx010PrepareResult prepare(const Xid010& xid) = 0;
    
    virtual Dtx010RecoverResult recover(    ) = 0;
    
    virtual Dtx010RollbackResult rollback(const Xid010& xid) = 0;
    
    virtual void setTimeout(const Xid010& xid,
    uint32_t timeout) = 0;
    }; // class Dtx010Handler
    
    
    // ==================== class Exchange010Handler ====================
    class Exchange010Handler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        Exchange010Handler(){};
        virtual ~Exchange010Handler() {}
        // Protocol methods
    
    virtual void declare(const string& name,
    const string& type,
    const string& alternateExchange,
    bool passive,
    bool durable,
    bool autoDelete,
    const FieldTable& arguments) = 0;
    
    virtual void delete_(const string& name,
    bool ifUnused) = 0;
    
    virtual Exchange010QueryResult query(const string& name) = 0;
    
    virtual void bind(const string& queue,
    const string& exchange,
    const string& bindingKey,
    const FieldTable& arguments) = 0;
    
    virtual void unbind(const string& queue,
    const string& exchange,
    const string& bindingKey) = 0;
    
    virtual Exchange010BoundResult bound(const string& queue,
    const string& exchange,
    const string& bindingKey,
    const FieldTable& arguments) = 0;
    }; // class Exchange010Handler
    
    
    // ==================== class Queue010Handler ====================
    class Queue010Handler {
        // Constructors and destructors
      public:
        class Invoker;              // Declared in ServerInvoker
          
        Queue010Handler(){};
        virtual ~Queue010Handler() {}
        // Protocol methods
    
    virtual void declare(const string& name,
    const string& alternateExchange,
    bool passive,
    bool durable,
    bool exclusive,
    bool autoDelete,
    const FieldTable& arguments) = 0;
    
    virtual void delete_(const string& name,
    bool ifUnused,
    bool ifEmpty) = 0;
    
    virtual void purge(const string& name) = 0;
    
    virtual Queue010QueryResult query(const string& name) = 0;
    }; // class Queue010Handler
    
    

    // Method handler get methods

    virtual ConnectionHandler* getConnectionHandler() = 0;
    virtual SessionHandler* getSessionHandler() = 0;
    virtual AccessHandler* getAccessHandler() = 0;
    virtual ExchangeHandler* getExchangeHandler() = 0;
    virtual QueueHandler* getQueueHandler() = 0;
    virtual BasicHandler* getBasicHandler() = 0;
    virtual FileHandler* getFileHandler() = 0;
    virtual StreamHandler* getStreamHandler() = 0;
    virtual TxHandler* getTxHandler() = 0;
    virtual DtxDemarcationHandler* getDtxDemarcationHandler() = 0;
    virtual DtxCoordinationHandler* getDtxCoordinationHandler() = 0;
    virtual TunnelHandler* getTunnelHandler() = 0;
    virtual MessageHandler* getMessageHandler() = 0;
    virtual BindingHandler* getBindingHandler() = 0;
    virtual ExecutionHandler* getExecutionHandler() = 0;
    virtual Connection010Handler* getConnection010Handler() = 0;
    virtual Session010Handler* getSession010Handler() = 0;
    virtual Execution010Handler* getExecution010Handler() = 0;
    virtual Message010Handler* getMessage010Handler() = 0;
    virtual Tx010Handler* getTx010Handler() = 0;
    virtual Dtx010Handler* getDtx010Handler() = 0;
    virtual Exchange010Handler* getExchange010Handler() = 0;
    virtual Queue010Handler* getQueue010Handler() = 0;
}; /* class AMQP_ServerOperations */
}}
#endif  /*!QPID_FRAMING_AMQP_SERVEROPERATIONS_H*/
